@@ -22,6 +22,7 @@ all_commands = (
     "build",
     "buildsource",
     "contents",
+    "desktophook",
     "hook",
     "info",
     "install",
@@ -32,6 +33,11 @@ all_commands = (
     )
 
 
+hidden_commands = (
+    "desktophook",
+    )
+
+
 def load_command(command):
     return importlib.import_module("click.commands.%s" % command)
 
@@ -39,6 +45,8 @@ def load_command(command):
 def help_text():
     lines = []
     for command in all_commands:
+        if command in hidden_commands:
+            continue
         mod = load_command(command)
         lines.append("  %-21s %s" % (command, mod.__doc__.splitlines()[0]))
     return "\n".join(lines)
