@@ -161,12 +161,20 @@ class TestClickHookSystemLevel(TestCase):
         with mkfile(os.path.join(
                 self.temp_dir, "test-1", "1.0", ".click", "info",
                 "test-1.manifest")) as f:
-            f.write(json.dumps({"hooks": {"test1-app": {"new": "target-1"}}}))
+            f.write(json.dumps({
+                "maintainer":
+                    b"Unic\xc3\xb3de <unicode@example.org>".decode("UTF-8"),
+                "hooks": {"test1-app": {"new": "target-1"}},
+            }))
         os.symlink("1.0", os.path.join(self.temp_dir, "test-1", "current"))
         with mkfile(os.path.join(
                 self.temp_dir, "test-2", "2.0", ".click", "info",
                 "test-2.manifest")) as f:
-            f.write(json.dumps({"hooks": {"test1-app": {"new": "target-2"}}}))
+            f.write(json.dumps({
+                "maintainer":
+                    b"Unic\xc3\xb3de <unicode@example.org>".decode("UTF-8"),
+                "hooks": {"test1-app": {"new": "target-2"}},
+            }))
         os.symlink("2.0", os.path.join(self.temp_dir, "test-2", "current"))
         with temp_hooks_dir(os.path.join(self.temp_dir, "hooks")):
             hook = ClickHook.open("new")
@@ -345,12 +353,20 @@ class TestClickHookUserLevel(TestCase):
         with mkfile(os.path.join(
                 self.temp_dir, "test-1", "1.0", ".click", "info",
                 "test-1.manifest")) as f:
-            f.write(json.dumps({"hooks": {"test1-app": {"new": "target-1"}}}))
+            f.write(json.dumps({
+                "maintainer":
+                    b"Unic\xc3\xb3de <unicode@example.org>".decode("UTF-8"),
+                "hooks": {"test1-app": {"new": "target-1"}},
+            }))
         user_db["test-1"] = "1.0"
         with mkfile(os.path.join(
                 self.temp_dir, "test-2", "2.0", ".click", "info",
                 "test-2.manifest")) as f:
-            f.write(json.dumps({"hooks": {"test1-app": {"new": "target-2"}}}))
+            f.write(json.dumps({
+                "maintainer":
+                    b"Unic\xc3\xb3de <unicode@example.org>".decode("UTF-8"),
+                "hooks": {"test1-app": {"new": "target-2"}},
+            }))
         user_db["test-2"] = "2.0"
         with temp_hooks_dir(os.path.join(self.temp_dir, "hooks")):
             hook = ClickHook.open("new")
